# IssuerClient

Object describing the properties of an IssuerClient
## Properties
Name | Type | Description | Notes
------------ | ------------- | ------------- | -------------
**id** | **str** | Unique identifier | [optional] [readonly] 
**issuer_id** | **str** | Unique identifier | [optional] [readonly] 
**name** | **str** | issuer client id | 
**secret** | **str** | issuer client secret | [optional] 
**application** | **str** | application associated with client | [optional] 
**org_id** | **str** | org_id associated with client | [optional] 
**redirects** | **list[str]** | List of redirect uris | [optional] 

[[Back to Model list]](../README.md#documentation-for-models) [[Back to API list]](../README.md#documentation-for-api-endpoints) [[Back to README]](../README.md)


